@@ -14,23 +14,11 @@
 package collector
 
 import (
-	"fmt"
 	"io/ioutil"
 	"strconv"
 	"strings"
 )
 
-func splitToInts(str string, sep string) (ints []int, err error) {
-	for _, part := range strings.Split(str, sep) {
-		i, err := strconv.Atoi(part)
-		if err != nil {
-			return nil, fmt.Errorf("could not split '%s' because %s is no int: %s", str, part, err)
-		}
-		ints = append(ints, i)
-	}
-	return ints, nil
-}
-
 func readUintFromFile(path string) (uint64, error) {
 	data, err := ioutil.ReadFile(path)
 	if err != nil {
